OC.L10N.register(
    "mail",
    {
    "Important" : "สำคัญ",
    "Work" : "ที่ทำงาน",
    "Personal" : "ส่วนตัว",
    "Mail" : "จดหมาย",
    "Connecting" : "กำลังเชื่อมต่อ",
    "Save" : "บันทึก",
    "Connect" : "เชื่อมต่อ",
    "Name" : "ชื่อ",
    "Password" : "รหัสผ่าน",
    "None" : "ไม่มี",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "รหัสผ่าน SMTP",
    "Signature" : "ลายเซ็น",
    "Go back" : "กลับไป",
    "Change name" : "เปลี่ยนชื่อ",
    "Email address" : "ที่อยู่อีเมล",
    "Cancel" : "ยกเลิก",
    "General" : "ทั่วไป",
    "Appearance" : "ลักษณะที่ปรากฏ",
    "Newest first" : "ใหม่ที่สุดก่อน",
    "Oldest first" : "เก่าที่สุดก่อน",
    "Privacy" : "ความเป็นส่วนตัว",
    "Security" : "ความปลอดภัย",
    "Archive" : "ที่เก็บถาวร",
    "Delete" : "ลบ",
    "Search" : "ค้นหา",
    "Send" : "ส่ง",
    "Refresh" : "รีเฟรช",
    "About" : "เกี่ยวกับ",
    "Ok" : "ตกลง",
    "Choose" : "เลือก",
    "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
    "Confirm" : "ยืนยัน",
    "Favorite" : "รายการโปรด",
    "Read" : "อ่าน",
    "Edit tags" : "แก้ไขแท็ก",
    "Back" : "ย้อนกลับ",
    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
    "Description" : "คำอธิบาย",
    "Create" : "สร้าง",
    "Select" : "เลือก",
    "Comment" : "ความคิดเห็น",
    "Accept" : "ยอมรับ",
    "Decline" : "ปฏิเสธ",
    "Remove" : "ลบออก",
    "Today" : "วันนี้",
    "Yesterday" : "เมื่อวาน",
    "Last week" : "สัปดาห์ที่แล้ว",
    "Last month" : "เดือนที่แล้ว",
    "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
    "Favorites" : "รายการโปรด",
    "Other" : "อื่น ๆ",
    "Forward" : "ส่งต่อ",
    "Translate" : "แปลภาษา",
    "Unnamed" : "ไม่มีชื่อ",
    "Choose a folder to store the attachment in" : "เลือกโฟลเดอร์ที่จะเก็บไฟล์แนบลงไป",
    "Move" : "ย้าย",
    "Moving" : "กำลังย้าย",
    "Remove account" : "ลบบัญชี",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Saving" : "กำลังบันทึก",
    "Show all folders" : "แสดงโฟลเดอร์ทั้งหมด",
    "Collapse folders" : "ยุบโฟลเดอร์",
    "Mark all as read" : "เปลี่ยนทั้งหมดเป็นอ่านแล้ว",
    "Rename" : "เปลี่ยนชื่อ",
    "Clear cache" : "ล้างแคช",
    "Reply" : "ตอบกลับ",
    "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
    "Add" : "เพิ่ม",
    "Clear" : "ล้าง",
    "Close" : "ปิด",
    "Date" : "วันที่",
    "Tags" : "แท็ก",
    "Custom" : "กำหนดเอง",
    "Tag already exists" : "มีแท็กอยู่แล้ว",
    "Not found" : "ไม่พบ",
    "Deleted" : "ลบแล้ว",
    "Help" : "ช่วยเหลือ",
    "Actions" : "การกระทำ",
    "Priority" : "ลำดับความสำคัญ",
    "delete" : "ลบ",
    "Edit" : "แก้ไข",
    "Reset" : "รีเซ็ต",
    "Client ID" : "รหัสไคลเอ็นต์",
    "Client secret" : "ข้อมูลลับไคลเอ็นต์",
    "User" : "ผู้ใช้",
    "Host" : "โฮสต์",
    "Port" : "พอร์ต",
    "Valid until" : "ใช้ได้จนถึง",
    "Certificate" : "ใบรับรอง",
    "Submit" : "ส่ง",
    "Group" : "กลุ่ม",
    "Shared" : "ถูกแชร์",
    "Shares" : "การแชร์",
    "Account connected" : "เชื่อมต่อบัญชีแล้ว",
    "All" : "ทั้งหมด",
    "Drafts" : "ฉบับร่าง",
    "All inboxes" : "กล่องขาเข้าทั้งหมด",
    "Inbox" : "กล่องขาเข้า",
    "Junk" : "อีเมลขยะ",
    "Sent" : "ส่งแล้ว",
    "Trash" : "ถังขยะ",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Error loading message" : "เกิดข้อผิดพลาดขณะโหลดข้อความ",
    "Redirect" : "เปลี่ยนเส้นทาง",
    "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
    "Continue to %s" : "ดำเนินการต่อไปที่ %s",
    "Last 7 days" : "ภายใน 7 วัน"
},
"nplurals=1; plural=0;");
